@@ -27,8 +27,15 @@ class StatementResource(BaseResource):
         else:
             return UnitError.from_json_api(response.json())
 
-    def list(self, offset: int = 0, limit: int = 100) -> Union[UnitResponse[List[StatementDTO]], UnitError]:
-        response = super().get(self.resource, {"page[limit]": limit, "page[offset]": offset})
+    def list(
+            self, offset: int = 0, limit: int = 100, account_id: str = None
+    ) -> Union[UnitResponse[List[StatementDTO]], UnitError]:
+        params = {
+            "page[limit]": limit, "page[offset]": offset
+        }
+        if account_id:
+            params["filter[accountId]"] = account_id
+        response = super().get(self.resource, params)
         if response.status_code == 200:
             data = response.json().get("data")
             return UnitResponse[StatementDTO](DtoDecoder.decode(data), None)
