@@ -18,8 +18,8 @@ class TransactionResource(BaseResource):
         else:
             return UnitError.from_json_api(response.json())
 
-    def list(self, offset: int = 0, limit: int = 100) -> Union[UnitResponse[List[TransactionDTO]], UnitError]:
-        response = super().get(self.resource, {"page[limit]": limit, "page[offset]": offset})
+    def list(self, offset: int = 0, limit: int = 100, account_id: Optional[str] = None, customer_id: Optional[str] = None) -> Union[UnitResponse[List[TransactionDTO]], UnitError]:
+        response = super().get(self.resource, {"page[limit]": limit, "page[offset]": offset, "filter[accountId]": account_id, "filter[customerId]": customer_id})
         if response.status_code == 200:
             data = response.json().get("data")
             included = response.json().get("included")
